@@ -1,7 +1,7 @@
 import logging
 from gql import gql
 from graphql import DocumentNode
-from typing import Any, AnyStr, Callable, Dict, List, Optional, Text, Tuple, Union
+from typing import Any, AnyStr, Callable, Dict, List, Optional, Tuple, Union
 
 from .api_resources.mutations import (
     BaseQuery,
@@ -15,7 +15,7 @@ from .api_resources.payload import (
     ForgeSubmitPayload,
     GeneratePDFPayload,
 )
-from .api_resources.requests import PlainRequest, RestRequest
+from .api_resources.requests import FullyQualifiedRequest, PlainRequest, RestRequest
 from .http import GQLClient, HTTPClient
 
 
@@ -117,6 +117,10 @@ class Anvil:
         api = RestRequest(self.client, options=options)
         return api
 
+    def request_fully_qualified(self, options: Optional[dict] = None):
+        api = FullyQualifiedRequest(self.client, options=options)
+        return api
+
     def fill_pdf(
         self, template_id: str, payload: Union[dict, AnyStr, FillPDFPayload], **kwargs
     ):
@@ -137,9 +141,7 @@ class Anvil:
             if isinstance(payload, dict):
                 data = FillPDFPayload(**payload)
             elif isinstance(payload, str):
-                data = FillPDFPayload.parse_raw(
-                    payload, content_type="application/json"
-                )
+                data = FillPDFPayload.model_validate_json(payload)
             elif isinstance(payload, FillPDFPayload):
                 data = payload
             else:
@@ -158,7 +160,7 @@ class Anvil:
         api = RestRequest(client=self.client)
         return api.post(
             f"fill/{template_id}.pdf",
-            data.dict(by_alias=True, exclude_none=True) if data else {},
+            data.model_dump(by_alias=True, exclude_none=True) if data else {},
             **kwargs,
         )
 
@@ -169,9 +171,7 @@ class Anvil:
         if isinstance(payload, dict):
             data = GeneratePDFPayload(**payload)
         elif isinstance(payload, str):
-            data = GeneratePDFPayload.parse_raw(
-                payload, content_type="application/json"
-            )
+            data = GeneratePDFPayload.model_validate_json(payload)
         elif isinstance(payload, GeneratePDFPayload):
             data = payload
         else:
@@ -180,7 +180,9 @@ class Anvil:
         # Any data errors would come from here
         api = RestRequest(client=self.client)
         return api.post(
-            "generate-pdf", data=data.dict(by_alias=True, exclude_none=True), **kwargs
+            "generate-pdf",
+            data=data.model_dump(by_alias=True, exclude_none=True),
+            **kwargs,
         )
 
     def get_cast(
@@ -326,7 +328,7 @@ class Anvil:
 
         return _get_return(res, get_data=get_data)
 
-    def get_weld(self, eid: Text, **kwargs):
+    def get_weld(self, eid: str, **kwargs):
         res = self.query(
             gql(
                 """
@@ -380,9 +382,7 @@ class Anvil:
             raise TypeError('One of the arguments `payload` or `json` must exist')
 
         if json:
-            payload = CreateEtchPacketPayload.parse_raw(
-                json, content_type="application/json"
-            )
+            payload = CreateEtchPacketPayload.model_validate_json(json)
 
         if isinstance(payload, dict):
             mutation = CreateEtchPacket.create_from_dict(payload)
@@ -396,7 +396,7 @@ class Anvil:
             )
 
         payload = mutation.create_payload()
-        variables = payload.dict(by_alias=True, exclude_none=True)
+        variables = payload.model_dump(by_alias=True, exclude_none=True)
 
         return self.mutate(mutation, variables=variables, upload_files=True, **kwargs)
 
@@ -407,7 +407,9 @@ class Anvil:
             client_user_id=client_user_id,
         )
         payload = mutation.create_payload()
-        return self.mutate(mutation, variables=payload.dict(by_alias=True), **kwargs)
+        return self.mutate(
+            mutation, variables=payload.model_dump(by_alias=True), **kwargs
+        )
 
     def download_documents(self, document_group_eid: str, **kwargs):
         """Retrieve all completed documents in zip form."""
@@ -416,7 +418,7 @@ class Anvil:
 
     def forge_submit(
         self,
-        payload: Optional[Union[Dict[Text, Any], ForgeSubmitPayload]] = None,
+        payload: Optional[Union[Dict[str, Any], ForgeSubmitPayload]] = None,
         json=None,
         **kwargs,
     ) -> Dict[str, Any]:
@@ -425,9 +427,7 @@ class Anvil:
             raise TypeError('One of arguments `json` or `payload` are required')
 
         if json:
-            payload = ForgeSubmitPayload.parse_raw(
-                json, content_type="application/json"
-            )
+            payload = ForgeSubmitPayload.model_validate_json(json)
 
         if isinstance(payload, dict):
             mutation = ForgeSubmit.create_from_dict(payload)
@@ -440,6 +440,8 @@ class Anvil:
 
         return self.mutate(
             mutation,
-            variables=mutation.create_payload().dict(by_alias=True, exclude_none=True),
+            variables=mutation.create_payload().model_dump(
+                by_alias=True, exclude_none=True
+            ),
             **kwargs,
         )
